#!/usr/bin/env python

# UR5 PICK & PLACE. PYTHON SCRIPT

import sys
import copy
import rospy
import moveit_commander
import moveit_msgs.msg
import geometry_msgs.msg
import control_msgs.msg
import actionlib
import tf
from math import pi
from std_msgs.msg import String
from moveit_commander.conversions import pose_to_list

CONV = pi/180

#def talker(action):
    #pub = rospy.Publisher('gripper_call', String, queue_size=10)
    #pub.publish(action)
       
if __name__ == '__main__':
    try:

	# We initialize the node:
	rospy.init_node('robot_control', anonymous=True)

	# We initialize moveit_commander, and robot, scene and arm (manipulator) groups:
        moveit_commander.roscpp_initialize(sys.argv)
	robot = moveit_commander.RobotCommander() 
	scene = moveit_commander.PlanningSceneInterface()
	group_name="manipulator"
	move_group = moveit_commander.MoveGroupCommander(group_name)

	# SPEED AND ACCELERATION SET-UP:
	moveit_commander.move_group.MoveGroupCommander.set_max_velocity_scaling_factor(move_group, 1)
	moveit_commander.move_group.MoveGroupCommander.set_max_acceleration_scaling_factor(move_group, 1)	

        # ------ PICK and PLACE of the BOX 1 ------

	# 1. Home Position:
	print "1. STEP: MOVING ROBOT TO HOME POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 0
	joint_goal[1] = CONV * -90
	joint_goal[2] = CONV * -90
	joint_goal[3] = CONV * 0
	joint_goal[4] = CONV * 0
	joint_goal[5] = CONV * 0
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	# 2. Box1 Approach Position:
	print "2. STEP: MOVING ROBOT TO B1_APPROACH POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 65
	joint_goal[1] = CONV * -120
	joint_goal[2] = CONV * -57
	joint_goal[3] = CONV * -1
	joint_goal[4] = CONV * 25
	joint_goal[5] = CONV * -2
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	# 3. Box1 Pick Position:
	print "3. STEP: MOVING ROBOT TO B1_PICK POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 56
	joint_goal[1] = CONV * -134
	joint_goal[2] = CONV * -34
	joint_goal[3] = CONV * -9
	joint_goal[4] = CONV * 34
	joint_goal[5] = CONV * -2
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(2)

	# 4. Close GRIPPER:
	print "4. STEP: CLOSING GRIPPER"
	#talker("close")
	COND = str("init")
	while (COND=="init"):
		print "Type OK if gripper has been closed:"
		COND = str(input())
		if (COND=="OK"):
			pass
		else:
			COND = "init"

	moveit_commander.move_group.MoveGroupCommander.set_max_velocity_scaling_factor(move_group, 0.1)
	moveit_commander.move_group.MoveGroupCommander.set_max_acceleration_scaling_factor(move_group, 0.1)


	# 5. Box1 Lift Position:
	print "5. STEP: MOVING ROBOT TO B1_LIFT POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 76
	joint_goal[1] = CONV * -118
	joint_goal[2] = CONV * -35
	joint_goal[3] = CONV * -20
	joint_goal[4] = CONV * 14
	joint_goal[5] = CONV * -6
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	moveit_commander.move_group.MoveGroupCommander.set_max_velocity_scaling_factor(move_group, 1)
	moveit_commander.move_group.MoveGroupCommander.set_max_acceleration_scaling_factor(move_group, 1)

	# 6. Box1 Place Position:
	print "6. STEP: MOVING ROBOT TO B1_PLACE POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 66
	joint_goal[1] = CONV * -23
	joint_goal[2] = CONV * 71
	joint_goal[3] = CONV * -51
	joint_goal[4] = CONV * 154
	joint_goal[5] = CONV * -4
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	# 7. Open GRIPPER:
	print "7. STEP: OPENING GRIPPER"
	#talker("close")
	COND = str("init")
	while (COND=="init"):
		print "Type OK if gripper has been opened:"
		COND = str(input())
		if (COND=="OK"):
			pass
		else:
			COND = "init"

	# 8. Home Position:
	print "LAST STEP: MOVING ROBOT TO HOME POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 0
	joint_goal[1] = CONV * -90
	joint_goal[2] = CONV * -90
	joint_goal[3] = CONV * 0
	joint_goal[4] = CONV * 0
	joint_goal[5] = CONV * 0
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)


    except rospy.ROSInterruptException:
        print ("Program interrupted before completion!")

