#!/usr/bin/env python

# UR5 PICK & PLACE. PYTHON SCRIPT

import sys
import copy
import rospy
import moveit_commander
import moveit_msgs.msg
import geometry_msgs.msg
import control_msgs.msg
import actionlib
import tf
from math import pi
from std_msgs.msg import String
from moveit_commander.conversions import pose_to_list

CONV = pi/180

if __name__ == '__main__':
    try:

	# We initialize the node:
	rospy.init_node('robot_control', anonymous=True)

	# We initialize moveit_commander, and robot, scene and arm (manipulator) groups:
        moveit_commander.roscpp_initialize(sys.argv)
	robot = moveit_commander.RobotCommander() 
	scene = moveit_commander.PlanningSceneInterface()
	group_name="manipulator"
	gripper_name="gripper"
	move_group = moveit_commander.MoveGroupCommander(group_name)
	move_gripper = moveit_commander.MoveGroupCommander(gripper_name)
        

        # ------ PICK and PLACE of the BOX 1 ------

	# 1. Home Position:
	print "1. STEP: MOVING ROBOT TO HOME POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 0
	joint_goal[1] = CONV * -90
	joint_goal[2] = CONV * -90
	joint_goal[3] = CONV * 0
	joint_goal[4] = CONV * 0
	joint_goal[5] = CONV * 0
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	# Initialize the gripper, by opening it:
	gripper_goal = move_gripper.get_current_joint_values()
	gripper_goal[2] = 0.00
	move_gripper.go(gripper_goal, wait=True)
	rospy.sleep(1)

	# 2. Box1 Approach Position:
	print "2. STEP: MOVING ROBOT TO B1_APPROACH POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 65
	joint_goal[1] = CONV * -120
	joint_goal[2] = CONV * -57
	joint_goal[3] = CONV * -1
	joint_goal[4] = CONV * 25
	joint_goal[5] = CONV * -2
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	# 3. Box1 Pick Position:
	print "3. STEP: MOVING ROBOT TO B1_PICK POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 56
	joint_goal[1] = CONV * -135
	joint_goal[2] = CONV * -31
	joint_goal[3] = CONV * -12
	joint_goal[4] = CONV * 34
	joint_goal[5] = CONV * -2
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(2)

	# 4. Close GRIPPER:
	print "4. STEP: CLOSING GRIPPER"
	gripper_goal = move_gripper.get_current_joint_values()
	gripper_goal[2] = 0.38
	move_gripper.go(gripper_goal, wait=True)
	rospy.sleep(2)

	# 5. Box1 Lift Position:
	print "5. STEP: MOVING ROBOT TO B1_LIFT POSITION"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 56
	joint_goal[1] = CONV * -139
	joint_goal[2] = CONV * -17
	joint_goal[3] = CONV * -21
	joint_goal[4] = CONV * 34
	joint_goal[5] = CONV * -2
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

	# 6. Home Position:
	print "6. STEP: MOVING ROBOT TO ALL ZEROS"
	joint_goal = move_group.get_current_joint_values()
	joint_goal[0] = CONV * 0
	joint_goal[1] = CONV * 0
	joint_goal[2] = CONV * 0
	joint_goal[3] = CONV * 0
	joint_goal[4] = CONV * 0
	joint_goal[5] = CONV * 0
	
	move_group.go(joint_goal, wait=True)
	rospy.sleep(1)

    except rospy.ROSInterruptException:
        print ("Program interrupted before completion!")

