#!/usr/bin/env python

# CONTROL OF THE GRIPPER:

import sys
import copy
import rospy
import moveit_commander
import moveit_msgs.msg
import geometry_msgs.msg
import control_msgs.msg
import actionlib
from math import pi
from std_msgs.msg import String
from moveit_commander.conversions import pose_to_list

CLOSED_POS = 0.40   # The position for a fully-opened gripper (meters)
OPENED_POS = 0.0  # The position for a fully-closed gripper (meters)
ACTION_SERVER = '/gripper_controller/gripper_cmd'

class Gripper(object):

	def __init__(self):
        	self._client = actionlib.SimpleActionClient(ACTION_SERVER, control_msgs.msg.GripperCommandAction)

	def open(self):
		goal = control_msgs.msg.GripperCommandGoal()
		goal.command.position = OPENED_POS
		goal.command.max_effort = -1.0
		self._client.send_goal(goal)

	def close(self):
		goal = control_msgs.msg.GripperCommandGoal()
		goal.command.position = CLOSED_POS
		goal.command.max_effort = -1.0
		self._client.send_goal(goal)

if __name__ == '__main__':
    try:

	# moveit_commander.roscpp_initialize(sys.argv)
        rospy.init_node('gripper_command')
        gripper = Gripper() # We instantiate the "Gripper" class

        # TRIAL
        print "CLOSING GRIPPER IN..."
        rospy.sleep(1)
        print "3"
        rospy.sleep(1)
        print "2"
        rospy.sleep(1)
        print "1"
        rospy.sleep(1)

	gripper.close()

    except rospy.ROSInterruptException:
        print ("Program interrupted before completion!")

